Camper
===========

[![PyPI version shields.io](https://img.shields.io/pypi/v/camper.svg)](https://pypi.python.org/pypi/camper/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/camper.svg)](https://pypi.python.org/pypi/camper/)
[![PyPI license](https://img.shields.io/pypi/l/camper.svg)](https://pypi.python.org/pypi/camper/)
[![PyPI status](https://img.shields.io/pypi/status/camper.svg)](https://pypi.python.org/pypi/camper/)

```python
import caravan

```